==> iReport-1.2.4-src.zip: iReport-1.2.4-src/src/it/businesslogic/ireport/chart/HighLowPlot.java <==
/*
 * PiePlot.java
 *
 * Created on 16 agosto 2005, 10.19
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;

/**
 *
 * @author Administrator
 */
public class HighLowPlot extends Plot{
    
    private boolean showCloseTicks = true;
    private boolean showOpenTicks = true;
    
    private String timeAxisLabelExpression = "";
    private String valueAxisLabelExpression = "";
    
    /** Creates a new instance of PiePlot */
    public HighLowPlot() {
    }
  
    public String getTimeAxisLabelExpression() {
        return timeAxisLabelExpression;
    }

    public void setTimeAxisLabelExpression(String timeAxisLabelExpression) {
        this.timeAxisLabelExpression = timeAxisLabelExpression;
    }

    public String getValueAxisLabelExpression() {
        return valueAxisLabelExpression;
    }

    public void setValueAxisLabelExpression(String valueAxisLabelExpression) {
        this.valueAxisLabelExpression = valueAxisLabelExpression;
    }

    public boolean isShowCloseTicks() {
        return showCloseTicks;
    }

    public void setShowCloseTicks(boolean showCloseTicks) {
        this.showCloseTicks = showCloseTicks;
    }

    public boolean isShowOpenTicks() {
        return showOpenTicks;
    }

    public void setShowOpenTicks(boolean showOpenTicks) {
        this.showOpenTicks = showOpenTicks;
    }
    
     public Plot cloneMe()
    {
        HighLowPlot obj = new HighLowPlot();
        copyBasePlot(obj);
        obj.setShowCloseTicks( this.isShowCloseTicks());
        obj.setShowOpenTicks( this.isShowOpenTicks());
        obj.setTimeAxisLabelExpression( this.getTimeAxisLabelExpression());
        obj.setValueAxisLabelExpression( this.getValueAxisLabelExpression());
       
        return obj;
    }
}

==> iReport-1.2.7-src.zip: iReport-1.2.7-src/src/it/businesslogic/ireport/chart/HighLowPlot.java <==
/*
 * PiePlot.java
 *
 * Created on 16 agosto 2005, 10.19
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;

/**
 *
 * @author Administrator
 */
public class HighLowPlot extends Plot{
    
    private boolean showCloseTicks = true;
    private boolean showOpenTicks = true;
    
    private String timeAxisLabelExpression = "";
    private String valueAxisLabelExpression = "";
    
    private AxisFormat timeAxisFormat = new AxisFormat();
    private AxisFormat valueAxisFormat = new AxisFormat();
    
    /** Creates a new instance of PiePlot */
    public HighLowPlot() {
    }
  
    public String getTimeAxisLabelExpression() {
        return timeAxisLabelExpression;
    }

    public void setTimeAxisLabelExpression(String timeAxisLabelExpression) {
        this.timeAxisLabelExpression = timeAxisLabelExpression;
    }

    public String getValueAxisLabelExpression() {
        return valueAxisLabelExpression;
    }

    public void setValueAxisLabelExpression(String valueAxisLabelExpression) {
        this.valueAxisLabelExpression = valueAxisLabelExpression;
    }

    public boolean isShowCloseTicks() {
        return showCloseTicks;
    }

    public void setShowCloseTicks(boolean showCloseTicks) {
        this.showCloseTicks = showCloseTicks;
    }

    public boolean isShowOpenTicks() {
        return showOpenTicks;
    }

    public void setShowOpenTicks(boolean showOpenTicks) {
        this.showOpenTicks = showOpenTicks;
    }
    
     public Plot cloneMe()
    {
        HighLowPlot obj = new HighLowPlot();
        copyBasePlot(obj);
        obj.setShowCloseTicks( this.isShowCloseTicks());
        obj.setShowOpenTicks( this.isShowOpenTicks());
        obj.setTimeAxisLabelExpression( this.getTimeAxisLabelExpression());
        obj.setValueAxisLabelExpression( this.getValueAxisLabelExpression());
        
        obj.setTimeAxisFormat( getTimeAxisFormat().cloneMe());
        obj.setValueAxisFormat( getValueAxisFormat().cloneMe());
       
       
        return obj;
    }

    public AxisFormat getTimeAxisFormat() {
        return timeAxisFormat;
    }

    public void setTimeAxisFormat(AxisFormat timeAxisFormat) {
        this.timeAxisFormat = timeAxisFormat;
    }

    public AxisFormat getValueAxisFormat() {
        return valueAxisFormat;
    }

    public void setValueAxisFormat(AxisFormat valueAxisFormat) {
        this.valueAxisFormat = valueAxisFormat;
    }
}
